Index: UPGRADE.txt
===================================================================
--- UPGRADE.txt	(revision 330825)
+++ UPGRADE.txt	(working copy)
@@ -22,7 +22,10 @@
 
 From 10 to 12:
 
-* No significant changes as of yet.
+func_enum:
+ - ENUM query functions now return a count of -1 on lookup error to
+   differentiate between a failed query and a successful query with 0 results
+   matching the specified type.
 
 From 1.8 to 10:
 
Index: funcs/func_enum.c
===================================================================
--- funcs/func_enum.c	(revision 330825)
+++ funcs/func_enum.c	(working copy)
@@ -82,7 +82,7 @@
 				<para>The number of the result that you want to retrieve.</para>
 				<para>Results start at <literal>1</literal>. If this argument is specified
 				as <literal>getnum</literal>, then it will return the total number of results 
-				that are available.</para>
+				that are available or -1 on error.</para>
 			</parameter>
 		</syntax>
 		<description>
@@ -105,7 +105,7 @@
 					<option name="c">
 						<para>Returns an integer count of the number of NAPTRs of a certain RR type.</para>
 						<para>Combination of <literal>c</literal> and Method-type of <literal>ALL</literal> will
-						return a count of all NAPTRs for the record.</para>
+						return a count of all NAPTRs for the record or -1 on error.</para>
 					</option>
 					<option name="u">
 						<para>Returns the full URI and does not strip off the URI-scheme.</para>
@@ -363,7 +363,7 @@
 	erds = datastore->data;
 
 	if (!strcasecmp(args.resultnum, "getnum")) {
-		snprintf(buf, len, "%u", erds->context->naptr_rrs_count);
+		snprintf(buf, len, "%d", erds->context->naptr_rrs_count);
 		res = 0;
 		goto finish;
 	}
Index: main/enum.c
===================================================================
--- main/enum.c	(revision 330825)
+++ main/enum.c	(working copy)
@@ -851,14 +851,18 @@
 	ret = ast_search_dns(context, tmp, C_IN, T_NAPTR, enum_callback);
 	time_end = ast_tvnow();
 
-	ast_debug(2, "profiling: %s, %s, %" PRIi64 " ms\n",
-			(ret == 0) ? "OK" : "FAIL", tmp, ast_tvdiff_ms(time_end, time_start));
+	ast_debug(2, "profiling: %d, %s, %" PRIi64 " ms\n",
+			ret, tmp, ast_tvdiff_ms(time_end, time_start));
 
-	if (ret < 0) {
-		ast_debug(1, "No such number found: %s (%s)\n", tmp, strerror(errno));
+	if (ret == 0) {
+		ast_debug(1, "Need more digits for: %s\n", tmp);
 		strcpy(dst, "0");
-		ret = 0;
-	}
+	} else if (ret < 0) {
+ 		ast_debug(1, "No such number found: %s (%s)\n", tmp, strerror(errno));
+		context->naptr_rrs_count = -1;
+ 		strcpy(dst, "0");
+ 		ret = 0;
+ 	}
 
 	if (context->naptr_rrs_count >= context->position && ! (context->options & ENUMLOOKUP_OPTIONS_COUNT)) {
 		/* sort array by NAPTR order/preference */
@@ -896,7 +900,7 @@
 	} else if (!(context->options & ENUMLOOKUP_OPTIONS_COUNT)) {
 		context->dst[0] = 0;
 	} else if ((context->options & ENUMLOOKUP_OPTIONS_COUNT)) {
-		snprintf(context->dst, context->dstlen, "%d", context->count);
+		snprintf(context->dst, context->dstlen, "%d", context->naptr_rrs_count + context->count);
 	}
 
 	if (chan) {
